@@ -21,8 +21,8 @@ unless (defined $Test::Deep::NoTest::NoTest)
 
 our ($Stack, %Compared, $CompareCache, %WrapCache, $Shallow);
 
-our $VERSION = '0.110';
-$VERSION = eval $VERSION;
+our $VERSION = '1.120';
+$VERSION =~ tr/_//d;
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -34,7 +34,7 @@ our $DNE = \"";
 our $DNE_ADDR = Scalar::Util::refaddr($DNE);
 
 # if no sub name is supplied then we use the package name in lower case
-my %constructors = (
+my @constructors = (
   All               => "",
   Any               => "",
   Array             => "",
@@ -53,7 +53,9 @@ my %constructors = (
   Isa               => "Isa",
   ListMethods       => "",
   Methods           => "",
+  None              => "",
   Number            => "num",
+  Obj               => "obj_isa",
   RefType           => "",
   Regexp            => "re",
   RegexpMatches     => "",
@@ -66,9 +68,9 @@ my %constructors = (
   String            => "str",
 );
 
-our @CONSTRUCTORS_FROM_CLASSES;
+my @CONSTRUCTORS_FROM_CLASSES;
 
-while (my ($pkg, $name) = each %constructors)
+while (my ($pkg, $name) = splice @constructors, 0, 2)
 {
 	$name = lc($pkg) unless $name;
 	my $full_pkg = "Test::Deep::$pkg";
@@ -90,16 +92,32 @@ while (my ($pkg, $name) = each %constructors)
   our @EXPORT_OK = qw( descend render_stack class_base cmp_details deep_diag );
 
   our %EXPORT_TAGS;
+  $EXPORT_TAGS{preload} = [];
   $EXPORT_TAGS{v0} = [
     qw(
       Isa
+      blessed
+      obj_isa
 
       all any array array_each arrayelementsonly arraylength arraylengthonly
-      bag blessed bool cmp_bag cmp_deeply cmp_methods cmp_set code eq_deeply
+      bag bool cmp_bag cmp_deeply cmp_methods cmp_set code eq_deeply
       hash hash_each hashkeys hashkeysonly ignore isa listmethods methods
-      noclass num re reftype regexpmatches regexponly regexpref regexprefonly
-      scalarrefonly scalref set shallow str subbagof subhashof subsetof
-      superbagof superhashof supersetof useclass
+      noclass none noneof num re reftype regexpmatches regexponly regexpref
+      regexprefonly scalarrefonly scalref set shallow str subbagof subhashof
+      subsetof superbagof superhashof supersetof useclass
+    )
+  ];
+
+  $EXPORT_TAGS{v1} = [
+    qw(
+      obj_isa
+
+      all any array array_each arrayelementsonly arraylength arraylengthonly
+      bag bool cmp_bag cmp_deeply cmp_methods cmp_set code eq_deeply
+      hash hash_each hashkeys hashkeysonly ignore listmethods methods
+      noclass none noneof num re reftype regexpmatches regexponly regexpref
+      regexprefonly scalarrefonly scalref set shallow str subbagof subhashof
+      subsetof superbagof superhashof supersetof useclass
     )
   ];
 
@@ -108,6 +126,56 @@ while (my ($pkg, $name) = each %constructors)
   $EXPORT_TAGS{all} = [ @EXPORT, @EXPORT_OK ];
 }
 
+sub import {
+  my $self = shift;
+  my @sans_preload = grep {; $_ ne ':preload' } @_;
+  if (@_ != @sans_preload) {
+    require Test::Deep::All;
+    require Test::Deep::Any;
+    require Test::Deep::Array;
+    require Test::Deep::ArrayEach;
+    require Test::Deep::ArrayElementsOnly;
+    require Test::Deep::ArrayLength;
+    require Test::Deep::ArrayLengthOnly;
+    require Test::Deep::Blessed;
+    require Test::Deep::Boolean;
+    require Test::Deep::Cache::Simple;
+    require Test::Deep::Cache;
+    require Test::Deep::Class;
+    require Test::Deep::Cmp;
+    require Test::Deep::Code;
+    require Test::Deep::Hash;
+    require Test::Deep::HashEach;
+    require Test::Deep::HashElements;
+    require Test::Deep::HashKeys;
+    require Test::Deep::HashKeysOnly;
+    require Test::Deep::Ignore;
+    require Test::Deep::Isa;
+    require Test::Deep::ListMethods;
+    require Test::Deep::Methods;
+    require Test::Deep::MM;
+    require Test::Deep::None;
+    require Test::Deep::Number;
+    require Test::Deep::Obj;
+    require Test::Deep::Ref;
+    require Test::Deep::RefType;
+    require Test::Deep::Regexp;
+    require Test::Deep::RegexpMatches;
+    require Test::Deep::RegexpOnly;
+    require Test::Deep::RegexpRef;
+    require Test::Deep::RegexpRefOnly;
+    require Test::Deep::RegexpVersion;
+    require Test::Deep::ScalarRef;
+    require Test::Deep::ScalarRefOnly;
+    require Test::Deep::Set;
+    require Test::Deep::Shallow;
+    require Test::Deep::Stack;
+    require Test::Deep::String;
+  }
+
+  $self->export_to_level(1, $self, @_);
+}
+
 # this is ugly, I should never have exported a sub called isa now I
 # have to try figure out if the recipient wanted my isa or if a class
 # imported us and UNIVERSAL::isa is being called on that class.
@@ -275,7 +343,7 @@ sub descend
 	if (! $Expects and Scalar::Util::blessed($d1) and $d1->isa("Test::Deep::Cmp"))
 	{
 		my $where = $Stack->render('$data');
-		confess "Found a special comparison in $where\nYou can only the specials in the expects structure";
+		confess "Found a special comparison in $where\nYou can only use specials in the expects structure";
 	}
 
 	if (ref $d1 and ref $d2)
@@ -320,7 +388,7 @@ sub descend
 
 	if (ref($d1) and (Scalar::Util::refaddr($d1) == $DNE_ADDR))
 	{
-		# whatever it was suposed to be, it didn't exist and so it's an
+		# whatever it was supposed to be, it didn't exist and so it's an
 		# automatic fail
 		return 0;
 	}
@@ -432,7 +500,7 @@ sub requireclass
 	return Test::Deep::Class->new(1, $val);
 }
 
-# docs and export say this is call useclass, doh!
+# docs and export say this is called useclass, doh!
 
 *useclass = \&requireclass;
 
@@ -466,6 +534,13 @@ sub subsetof
 	return Test::Deep::Set->new(1, "sub", @_);
 }
 
+sub noneof
+{
+        require Test::Deep::Set;
+
+        return Test::Deep::Set->new(1, "none", @_);
+}
+
 sub cmp_set
 {
 	local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -592,6 +667,8 @@ don't know exactly what the string should be but you do know some things
 about how it should look, C<eq> is no good and you must use pattern matching
 instead. Test::Deep provides pattern matching for complex data structures
 
+Test::Deep has B<I<a lot>> of exports.  See L</EXPORTS> below.
+
 =head1 EXAMPLES
 
 How Test::Deep works is much easier to understand by seeing some examples.
@@ -742,7 +819,7 @@ include themselves. Simply do
     # note no mention of Children here
   };
 
-  $person_cmp->{Children} = each_array($person_cmp);
+  $person_cmp->{Children} = array_each($person_cmp);
 
   cmp_deeply($person, $person_cmp, "person ok");
 
@@ -961,7 +1038,7 @@ C<$thing> it will go back to it's previous setting for checking class.
 
 This can be useful when you want to check that objects have been
 constructed correctly but you don't want to write lots of
-C<bless>es. If \@people is an array of Person objects then
+C<bless>es. If @people is an array of Person objects then
 
   cmp_deeply(\@people, noclass([
     bless {name => 'John', phone => '555-5555'}, "Person",
@@ -979,7 +1056,7 @@ However, this is testing so you should also check that the objects are
 blessed correctly. You could use a map to bless all those hashes or you
 could do a second test like
 
-  cmp_deeply($people, array_each(isa("Person"));
+  cmp_deeply(\@people, array_each(isa("Person"));
 
 =head3 useclass($thing)
 
@@ -1021,7 +1098,7 @@ is the equivalent of
 
 With $capture_data
 
-  cmp_deeply($got, [re($regex, $capture_data])
+  cmp_deeply($got, [re($regex, $capture_data)])
 
 is the equivalent of
 
@@ -1030,7 +1107,7 @@ is the equivalent of
 
 So you can do something simple like
 
-  cmp_deeply($got, re(qr/(\d\d)(\w\w)/, [25, "ab" ])
+  cmp_deeply($got, re(qr/(\d\d)(\w\w)/, [25, "ab" ]))
 
 to check that (\d\d) was 25 and (\w\w) was "ab" but you can also use
 Test::Deep objects to do more complex testing of the captured values
@@ -1121,15 +1198,15 @@ will be a pass.
 
 The object returned by set() has an add() method.
 
-  my $set = set(1, 2, 3);
-  $set->add(4, 5, 6);
+  my $set = set(1, 2);
+  $set->add(1, 3, 1);
 
-will result in a set containing 1, 2, 3, 4, 5, 5.
+will result in a set containing 1, 2, 3.
 
 C<NOTE> See the NOTE on the bag() comparison for some dangers in using
 special comparisons inside set()
 
-=head3 superbagof(@elements), subbagof(@elements), supersetof(@elements) and subsetof(@elements)
+=head3 superbagof(@elements), subbagof(@elements), supersetof(@elements), subsetof(@elements) and noneof(@elements)
 
 @elements is an array of elements.
 
@@ -1139,9 +1216,13 @@ These do exactly what you'd expect them to do, so for example
 
 checks that @$data contains at most 2 "1"s, 1 "3" and 1 "4" and
 
-  cmp_deeply($data, supersetof(1, 4));
+  cmp_deeply($data, supersetof(1, 1, 1, 4));
 
-check that @$data contains at least 1 "1" and 1 "4".
+will check that @$data has at least one "1" and at least one "4".
+
+  cmp_deeply($data, noneof(1, 2, 3));
+
+will check that @$data does not contain any instances of "1", "2" or "3".
 
 These are just special cases of the Set and Bag comparisons so they also
 give you an add() method and they also have the same limitations when using
@@ -1168,13 +1249,13 @@ for all failures. When reporting failure, the parts are counted from 1.
 
 Thanks to the magic of overloading, you can write
 
-  all(isa("Person"), methods(name => 'John'), re("^wi"))
+  any( re("^wi"), all(isa("Person"), methods(name => 'John')) )
 
 as
 
-  isa("Person") & methods(name => 'John') | re("^wi")
+   re("^wi") | isa("Person") & methods(name => 'John')
 
-Note B<single> | not double as || cannot be overloaded. This will only work
+Note B<single> | not double, as || cannot be overloaded. This will only work
 when there is a special comparison involved. If you write
 
   "john" | "anne" | "robert"
@@ -1212,6 +1293,11 @@ a package that is used as a class. Without this, anyone calling
 C<Class-E<gt>isa($other_class)> would get the wrong answer. This is a
 hack to patch over the fact that isa is exported by default.
 
+=head3 obj_isa($class)
+
+This test accepts only objects that are instances of C<$class> or a subclass.
+Unlike the C<Isa> test, this test will never accept class names.
+
 =head3 array_each($thing)
 
 $thing is a structure to be compared against.
@@ -1237,7 +1323,7 @@ is similar to
     cmp_deeply($got_v, $common_tests)
   }
 
-Except it will not explode is $got is not an array reference. It will check
+Except it will not explode if $got is not an array reference. It will check
 that each of the objects in @$got is a MyFile and that each one gives the
 correct results for it's methods.
 
@@ -1257,6 +1343,11 @@ size of each one you could do this
   )
   cmp_deeply($got, array_each($structure));
 
+=head3 hash_each($thing)
+
+This test behaves like C<array_each> (see above) but tests that each hash value
+passes its tests.
+
 =head3 str($string)
 
 $string is a string.
@@ -1315,7 +1406,7 @@ which gives an explanation of why it's a fail.
     }
   }
 
-  cmp_deeply("Brian", \&check_name);
+  cmp_deeply("Brian", code(\&check_name));
 
 =head1 DIAGNOSTIC FUNCTIONS
 
@@ -1446,6 +1537,29 @@ method should just return true or false.
 This gives you enough to write your own SCs but I haven't documented how
 diagnostics works because it's about to get an overhaul.
 
+=head1 EXPORTS
+
+By default, Test::Deep will export everything in its C<v0> tag, as if you had
+written:
+
+  use Test::Deep ':v0';
+
+Those things are:
+
+  all any array array_each arrayelementsonly arraylength arraylengthonly bag
+  blessed bool cmp_bag cmp_deeply cmp_methods cmp_set code eq_deeply hash
+  hash_each hashkeys hashkeysonly ignore Isa isa listmethods methods noclass
+  none noneof num obj_isa re reftype regexpmatches regexponly regexpref
+  regexprefonly scalarrefonly scalref set shallow str subbagof subhashof
+  subsetof superbagof superhashof supersetof useclass
+
+A slightly better set of exports is the C<v1> set.  It's all the same things,
+with the exception of C<Isa> and C<blessed>.  If you want to import
+"everything", you probably want to C<< use Test::Deep ':V1'; >>.
+
+There's another magic export group:  C<:preload>.  If that is specified, all of
+the Test::Deep plugins will be loaded immediately instead of lazily.
+
 =head1 SEE ALSO
 
 L<Test::More>
@@ -1460,8 +1574,8 @@ Fergal Daly E<lt>fergal@esatclear.ieE<gt>, with thanks to Michael G Schwern
 for Test::More's is_deeply function which inspired this.
 
 B<Please> do not bother Fergal Daly with bug reports.  Send them to the
-maintainer (above) or submit them at L<the request
-tracker|https://rt.cpan.org/Dist/Display.html?Queue=Test-Deep>.
+maintainer (above) or submit them at L<the issue
+tracker|https://github.com/rjbs/Test-Deep/issues>.
 
 =head1 COPYRIGHT
 
